==> eam-wshub-proxyclient-11.6-2-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/CreateEquipmentStructure.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOPLEVELONLY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLDEPENDENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLCOSTROLLUP" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "toplevelonly",
    "alldependent",
    "allcostrollup"
})
@XmlRootElement(name = "CreateEquipmentStructure")
public class CreateEquipmentStructure {

    @XmlElement(name = "TOPLEVELONLY", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String toplevelonly;
    @XmlElement(name = "ALLDEPENDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String alldependent;
    @XmlElement(name = "ALLCOSTROLLUP", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String allcostrollup;

    /**
     * Obtient la valeur de la propriété toplevelonly.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTOPLEVELONLY() {
        return toplevelonly;
    }

    /**
     * Définit la valeur de la propriété toplevelonly.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTOPLEVELONLY(String value) {
        this.toplevelonly = value;
    }

    /**
     * Obtient la valeur de la propriété alldependent.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLDEPENDENT() {
        return alldependent;
    }

    /**
     * Définit la valeur de la propriété alldependent.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLDEPENDENT(String value) {
        this.alldependent = value;
    }

    /**
     * Obtient la valeur de la propriété allcostrollup.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLCOSTROLLUP() {
        return allcostrollup;
    }

    /**
     * Définit la valeur de la propriété allcostrollup.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLCOSTROLLUP(String value) {
        this.allcostrollup = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/equipmentgeneration_001/CreateEquipmentStructure.java <==

package net.datastream.schemas.mp_entities.equipmentgeneration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOPLEVELONLY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLDEPENDENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLCOSTROLLUP" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "toplevelonly",
    "alldependent",
    "allcostrollup"
})
@XmlRootElement(name = "CreateEquipmentStructure")
public class CreateEquipmentStructure {

    @XmlElement(name = "TOPLEVELONLY", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String toplevelonly;
    @XmlElement(name = "ALLDEPENDENT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String alldependent;
    @XmlElement(name = "ALLCOSTROLLUP", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String allcostrollup;

    /**
     * Gets the value of the toplevelonly property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTOPLEVELONLY() {
        return toplevelonly;
    }

    /**
     * Sets the value of the toplevelonly property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTOPLEVELONLY(String value) {
        this.toplevelonly = value;
    }

    /**
     * Gets the value of the alldependent property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLDEPENDENT() {
        return alldependent;
    }

    /**
     * Sets the value of the alldependent property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLDEPENDENT(String value) {
        this.alldependent = value;
    }

    /**
     * Gets the value of the allcostrollup property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLCOSTROLLUP() {
        return allcostrollup;
    }

    /**
     * Sets the value of the allcostrollup property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLCOSTROLLUP(String value) {
        this.allcostrollup = value;
    }

}
